Product class

Example product model used for demonstrating model_guard usage.

Implemented types

Constructors

Product({required int id, required String title, required double price})
Creates a new Product.
Product.fromJson(Map<String, dynamic> json)
Creates a Product instance from JSON.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
id int
Product ID.
final
price double
Product price.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
Product title.
final

Methods

fromJson(Map<String, dynamic> json) GuardModel
Implementation required by GuardModel.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited