SafeParser class
Utility class that safely parses JSON into Dart models.
This class wraps model parsing in try-catch blocks so invalid API responses do not crash the application. Instead, it logs useful debugging information.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
parse<
T> ({required String modelName, required Map< String, dynamic> json, required T fromJson(Map<String, dynamic> )}) → T? - Parses a single JSON object into a model.
-
parseList<
T> ({required String modelName, required List jsonList, required T fromJson(Map< String, dynamic> )}) → List<T> - Parses a list of JSON objects into a list of models.